@@ -253,7 +253,7 @@ static int tsock_send_event(int fd, FAR struct daemon_priv_s *priv,
     }
 
   event.usockid = i + TEST_SOCKET_SOCKID_BASE;
-  event.events = events;
+  event.head.events = events;
 
   wlen = write(fd, &event, sizeof(event));
   if (wlen < 0)
@@ -377,8 +377,9 @@ static int socket_request(int fd, FAR struct daemon_priv_s *priv,
 
   /* Prepare response. */
 
-  resp.head.msgid = USRSOCK_MESSAGE_RESPONSE_ACK;
-  resp.head.flags = 0;
+  resp.head.msgid  = USRSOCK_MESSAGE_RESPONSE_ACK;
+  resp.head.flags  = 0;
+  resp.head.events = 0;
   resp.xid = req->head.xid;
   resp.result = socketid;
 
@@ -413,7 +414,8 @@ static int close_request(int fd, FAR struct daemon_priv_s *priv,
 
   /* Prepare response. */
 
-  resp.head.msgid = USRSOCK_MESSAGE_RESPONSE_ACK;
+  resp.head.msgid  = USRSOCK_MESSAGE_RESPONSE_ACK;
+  resp.head.events = 0;
   resp.xid = req->head.xid;
   if (priv->conf->delay_all_responses)
     {
@@ -551,8 +553,9 @@ prepare:
   /* Prepare response. */
 
   resp.xid = req->head.xid;
-  resp.head.msgid = USRSOCK_MESSAGE_RESPONSE_ACK;
-  resp.head.flags = 0;
+  resp.head.msgid  = USRSOCK_MESSAGE_RESPONSE_ACK;
+  resp.head.flags  = 0;
+  resp.head.events = 0;
 
   if (priv->conf->endpoint_block_connect)
     {
@@ -744,8 +747,9 @@ prepare:
   /* Prepare response. */
 
   resp.xid = req->head.xid;
-  resp.head.msgid = USRSOCK_MESSAGE_RESPONSE_ACK;
-  resp.head.flags = 0;
+  resp.head.msgid  = USRSOCK_MESSAGE_RESPONSE_ACK;
+  resp.head.flags  = 0;
+  resp.head.events = 0;
 
   if (priv->conf->delay_all_responses)
     {
@@ -880,8 +884,9 @@ prepare:
   /* Prepare response. */
 
   resp.reqack.xid = req->head.xid;
-  resp.reqack.head.msgid = USRSOCK_MESSAGE_RESPONSE_DATA_ACK;
-  resp.reqack.head.flags = 0;
+  resp.reqack.head.msgid  = USRSOCK_MESSAGE_RESPONSE_DATA_ACK;
+  resp.reqack.head.flags  = 0;
+  resp.reqack.head.events = 0;
 
   if (priv->conf->delay_all_responses)
     {
@@ -1071,8 +1076,9 @@ prepare:
   /* Prepare response. */
 
   resp.xid = req->head.xid;
-  resp.head.msgid = USRSOCK_MESSAGE_RESPONSE_ACK;
-  resp.head.flags = 0;
+  resp.head.msgid  = USRSOCK_MESSAGE_RESPONSE_ACK;
+  resp.head.flags  = 0;
+  resp.head.events = 0;
 
   if (priv->conf->delay_all_responses)
     {
@@ -1177,8 +1183,9 @@ prepare:
   /* Prepare response. */
 
   resp.reqack.xid = req->head.xid;
-  resp.reqack.head.msgid = USRSOCK_MESSAGE_RESPONSE_DATA_ACK;
-  resp.reqack.head.flags = 0;
+  resp.reqack.head.msgid  = USRSOCK_MESSAGE_RESPONSE_DATA_ACK;
+  resp.reqack.head.flags  = 0;
+  resp.reqack.head.events = 0;
 
   if (priv->conf->delay_all_responses)
     {
@@ -1288,8 +1295,9 @@ prepare:
   /* Prepare response. */
 
   resp.reqack.xid = req->head.xid;
-  resp.reqack.head.msgid = USRSOCK_MESSAGE_RESPONSE_DATA_ACK;
-  resp.reqack.head.flags = 0;
+  resp.reqack.head.msgid  = USRSOCK_MESSAGE_RESPONSE_DATA_ACK;
+  resp.reqack.head.flags  = 0;
+  resp.reqack.head.events = 0;
 
   if (priv->conf->delay_all_responses)
     {
@@ -1549,6 +1557,7 @@ static int establish_blocked_connection(int fd,
 
       priv->sockets_waiting_connect--;
       resp->head.flags &= ~USRSOCK_MESSAGE_FLAG_REQ_IN_PROGRESS;
+      resp->head.events = 0;
 
       wlen = write(fd, resp, sizeof(*resp));
       if (wlen < 0)
@@ -1600,6 +1609,7 @@ static int fail_blocked_connection(int fd, FAR struct daemon_priv_s *priv,
 
       priv->sockets_waiting_connect--;
       resp->head.flags &= ~USRSOCK_MESSAGE_FLAG_REQ_IN_PROGRESS;
+      resp->head.events = 0;
 
       wlen = write(fd, resp, sizeof(*resp));
       if (wlen < 0)
