@@ -26,7 +26,6 @@
 
 #include <cstdio>
 #include <cstdlib>
-#include <cunistd>
 #include <ctime>
 
 #include <sys/boardctl.h>
@@ -35,6 +34,7 @@
 #include <sched.h>
 #include <assert.h>
 #include <debug.h>
+#include <unistd.h>
 
 #include "nshlib/nshlib.h"
 
@@ -489,16 +489,16 @@ int CNxTerm::nxterm(int argc, char *argv[])
   std::fflush(stderr);
 
 #ifdef CONFIG_NXTERM_NXKBDIN
-  std::dup2(fd, 0);
+  dup2(fd, 0);
 #endif
-  std::dup2(fd, 1);
-  std::dup2(fd, 2);
+  dup2(fd, 1);
+  dup2(fd, 2);
 
   // And we can close our original driver file descriptor
 
   if (fd > 2)
     {
-      std::close(fd);
+      ::close(fd);
     }
 
   // Inform the parent thread that we successfully initialized
