@@ -214,6 +214,27 @@ int platform_user_verify(FAR const char *username, FAR const char *password);
 
 int nsh_system(int argc, FAR char *argv[]);
 
+/****************************************************************************
+ * Name: nsh_system_ctty
+ *
+ * Description:
+ *   This is the NSH-specific implementation of the standard system()
+ *   command.
+ *
+ *   NOTE:
+ *   This difference with nsh_system: newconsole set isctty true
+ *
+ * Input Parameters:
+ *   Standard task start-up arguments.  Expects argc == 2 with argv[1] being
+ *   the command to execute
+ *
+ * Returned Values:
+ *   EXIT_SUCCESS or EXIT_FAILURE
+ *
+ ****************************************************************************/
+
+int nsh_system_ctty(int argc, FAR char *argv[]);
+
 #undef EXTERN
 #ifdef __cplusplus
 }
