@@ -147,6 +147,21 @@ enum wapi_mode_e
   WAPI_MODE_MESH    = IW_MODE_MESH     /* Mesh (IEEE 802.11s) network */
 };
 
+/* Flags for encoding */
+
+enum wapi_encode_e
+{
+  WAPI_ENCODE_INDEX      = IW_ENCODE_INDEX,       /* Token index (if needed) */
+  WAPI_ENCODE_FLAGS      = IW_ENCODE_FLAGS,       /* Flags defined below */
+  WAPI_ENCODE_MODE       = IW_ENCODE_MODE,        /* Modes defined below */
+  WAPI_ENCODE_DISABLED   = IW_ENCODE_DISABLED,    /* Encoding disabled */
+  WAPI_ENCODE_ENABLED    = IW_ENCODE_ENABLED,     /* Encoding enabled */
+  WAPI_ENCODE_RESTRICTED = IW_ENCODE_RESTRICTED,  /* Refuse non-encoded packets */
+  WAPI_ENCODE_OPEN       = IW_ENCODE_OPEN,        /* Accept non-encoded packets */
+  WAPI_ENCODE_NOKEY      = IW_ENCODE_NOKEY,       /* Key is write only, so not present */
+  WAPI_ENCODE_TEMP       = IW_ENCODE_TEMP         /* Temporary key */
+};
+
 /* Bitrate flags.
  *
  * At the moment, unicast (IW_BITRATE_UNICAST) and broadcast
@@ -193,6 +208,8 @@ struct wapi_scan_info_s
   int bitrate;
   int has_rssi;
   int rssi;
+  int has_encode;
+  int encode;
 };
 
 /* Linked list container for routing table rows. */
@@ -254,13 +271,13 @@ enum wpa_alg_e
 
 struct wpa_wconfig_s
 {
-  uint8_t sta_mode;              /* Mode of operation, e.g. IW_MODE_INFRA */
+  enum wapi_mode_e sta_mode;     /* Mode of operation, e.g. IW_MODE_INFRA */
   uint8_t auth_wpa;              /* IW_AUTH_WPA_VERSION values, e.g.
                                   * IW_AUTH_WPA_VERSION_WPA2 */
   uint8_t cipher_mode;           /* IW_AUTH_PAIRWISE_CIPHER and
                                   * IW_AUTH_GROUP_CIPHER values, e.g.,
                                   * IW_AUTH_CIPHER_CCMP */
-  uint8_t alg;                   /* See enum wpa_alg_e above, e.g.
+  enum wpa_alg_e alg;            /* See enum wpa_alg_e above, e.g.
                                   * WPA_ALG_CCMP */
   double freq;                   /* Channel frequency */
   enum wapi_freq_flag_e flag;    /* Channel frequency flag */
@@ -714,6 +731,17 @@ void wapi_scan_coll_free(FAR struct wapi_list_s *aps);
 int wapi_set_country(int sock, FAR const char *ifname,
                      FAR const char *country);
 
+/****************************************************************************
+ * Name: wapi_get_country
+ *
+ * Description:
+ *    Get the country code
+ *
+ ****************************************************************************/
+
+int wapi_get_country(int sock, FAR const char *ifname,
+                     FAR char *country);
+
 /****************************************************************************
  * Name: wapi_get_sensitivity
  *
