@@ -63,6 +63,15 @@ int netlib_parseurl(FAR const char *str, FAR struct url_s *url)
   int ret = OK;
   size_t pathlen;
 
+  /* Each fields should have at least 1 byte to store
+   * the terminating NUL.
+   */
+
+  if (url->schemelen == 0 || url->hostlen == 0 || url->pathlen == 0)
+    {
+      return -EINVAL;
+    }
+
   /* extract the protocol field, a set of a-z letters */
 
   dest      = url->scheme;
@@ -174,6 +183,11 @@ int netlib_parseurl(FAR const char *str, FAR struct url_s *url)
       src++;
     }
 
+  /* Note: the current implementation does not distinguish
+   * an empty path and "/". While it's fine for HTTP, maybe it's
+   * cleaner to move the HTTP-specific normalization to the caller.
+   */
+
   *dest++ = '/';
   bytesleft--;
 
