@@ -66,6 +66,14 @@ static void usrsock_rpmsg_device_destroy(struct rpmsg_device *rdev,
 static int usrsock_rpmsg_ept_cb(struct rpmsg_endpoint *ept, void *data,
                                 size_t len, uint32_t src, void *priv);
 
+static void usrsock_rpmsg_ns_unbind(struct rpmsg_endpoint *ept);
+
+#ifdef CONFIG_NETDB_DNSCLIENT
+static int usrsock_rpmsg_send_dns_request(void *arg,
+                                          struct sockaddr *addr,
+                                          socklen_t addrlen);
+#endif
+
 /****************************************************************************
  * Private Functions
  ****************************************************************************/
@@ -82,9 +90,12 @@ static void usrsock_rpmsg_device_created(struct rpmsg_device *rdev,
 
       ret = rpmsg_create_ept(&priv->ept, rdev, USRSOCK_RPMSG_EPT_NAME,
                              RPMSG_ADDR_ANY, RPMSG_ADDR_ANY,
-                             usrsock_rpmsg_ept_cb, NULL);
+                             usrsock_rpmsg_ept_cb, usrsock_rpmsg_ns_unbind);
       if (ret == 0)
         {
+#ifdef CONFIG_NETDB_DNSCLIENT
+          dns_register_notify(usrsock_rpmsg_send_dns_request, priv);
+#endif
           sem_post(&priv->sem);
         }
     }
@@ -105,14 +116,13 @@ static void usrsock_rpmsg_device_destroy(struct rpmsg_device *rdev,
 static int usrsock_rpmsg_dns_handler(struct rpmsg_endpoint *ept, void *data,
                                      size_t len, uint32_t src, void *priv)
 {
-  int ret = OK;
 #ifdef CONFIG_NETDB_DNSCLIENT
   struct usrsock_rpmsg_dns_event_s *dns = data;
 
-  ret = dns_add_nameserver((struct sockaddr *)(dns + 1), dns->addrlen);
+  dns_add_nameserver((struct sockaddr *)(dns + 1), dns->addrlen);
 #endif
 
-  return ret;
+  return 0;
 }
 
 static int usrsock_rpmsg_default_handler(struct rpmsg_endpoint *ept,
@@ -155,6 +165,35 @@ static int usrsock_rpmsg_ept_cb(struct rpmsg_endpoint *ept, void *data,
   return ret;
 }
 
+#ifdef CONFIG_NETDB_DNSCLIENT
+static int usrsock_rpmsg_send_dns_request(void *arg,
+                                          struct sockaddr *addr,
+                                          socklen_t addrlen)
+{
+  struct usrsock_rpmsg_s *priv = arg;
+  struct rpmsg_endpoint *ept = &priv->ept;
+  struct usrsock_rpmsg_dns_request_s *dns;
+  uint32_t len;
+
+  dns = rpmsg_get_tx_payload_buffer(ept, &len, true);
+
+  dns->head.reqid = USRSOCK_RPMSG_DNS_REQUEST;
+  dns->head.xid = 0;
+  dns->head.reserved = 0;
+  dns->addrlen = addrlen;
+  memcpy(dns + 1, addr, addrlen);
+
+  return rpmsg_send_nocopy(ept, dns, sizeof(*dns) + addrlen);
+}
+#endif
+
+static void usrsock_rpmsg_ns_unbind(struct rpmsg_endpoint *ept)
+{
+#ifdef CONFIG_NETDB_DNSCLIENT
+  dns_unregister_notify(usrsock_rpmsg_send_dns_request, ept->priv);
+#endif
+}
+
 /****************************************************************************
  * Public Functions
  ****************************************************************************/
@@ -183,6 +222,7 @@ int main(int argc, char *argv[])
   ret = rpmsg_register_callback(&priv,
                                 usrsock_rpmsg_device_created,
                                 usrsock_rpmsg_device_destroy,
+                                NULL,
                                 NULL);
   if (ret < 0)
     {
@@ -279,6 +319,7 @@ unregister_callback:
   rpmsg_unregister_callback(&priv,
                             usrsock_rpmsg_device_created,
                             usrsock_rpmsg_device_destroy,
+                            NULL,
                             NULL);
 destroy_sem:
   sem_destroy(&priv.sem);
