@@ -25,6 +25,7 @@
 #include <nuttx/config.h>
 
 #include <sys/types.h>
+#include <inttypes.h>
 #include <stdint.h>
 #include <stdbool.h>
 
@@ -84,30 +85,6 @@
  * Private Functions
  ****************************************************************************/
 
-/****************************************************************************
- * Name: nsh_getdirpath
- ****************************************************************************/
-
-#if !defined(CONFIG_NSH_DISABLE_LS) || !defined(CONFIG_NSH_DISABLE_CP)
-static char *nsh_getdirpath(FAR struct nsh_vtbl_s *vtbl,
-                            FAR const char *path, FAR const char *file)
-{
-  /* Handle the case where all that is left is '/' */
-
-  if (strcmp(path, "/") == 0)
-    {
-      snprintf(vtbl->iobuffer, IOBUFFERSIZE, "/%s", file);
-    }
-  else
-    {
-      snprintf(vtbl->iobuffer, IOBUFFERSIZE, "%s/%s", path, file);
-    }
-
-  vtbl->iobuffer[PATH_MAX] = '\0';
-  return strdup(vtbl->iobuffer);
-}
-#endif
-
 /****************************************************************************
  * Name: ls_specialdir
  ****************************************************************************/
@@ -269,7 +246,7 @@ static int ls_handler(FAR struct nsh_vtbl_s *vtbl, FAR const char *dirpath,
 
       if ((lsflags & LSFLAGS_SIZE) != 0)
         {
-          nsh_output(vtbl, "%8d", buf.st_size);
+          nsh_output(vtbl, "%8" PRIdOFF, buf.st_size);
         }
     }
 
@@ -361,8 +338,9 @@ static int ls_recursive(FAR struct nsh_vtbl_s *vtbl, const char *dirpath,
 
           ret = nsh_foreach_direntry(vtbl, "ls", newpath, ls_recursive,
                                      pvarg);
-          free(newpath);
         }
+
+      free(newpath);
     }
 
   return ret;
@@ -477,7 +455,7 @@ int cmd_cat(FAR struct nsh_vtbl_s *vtbl, int argc, char **argv)
  * Name: cmd_dmesg
  ****************************************************************************/
 
-#if defined(CONFIG_RAMLOG_SYSLOG) && !defined(CONFIG_NSH_DISABLE_DMESG)
+#if defined(CONFIG_SYSLOG_DEVPATH) && !defined(CONFIG_NSH_DISABLE_DMESG)
 int cmd_dmesg(FAR struct nsh_vtbl_s *vtbl, int argc, char **argv)
 {
   return nsh_catfile(vtbl, argv[0], CONFIG_SYSLOG_DEVPATH);
@@ -693,6 +671,7 @@ int cmd_losetup(FAR struct nsh_vtbl_s *vtbl, int argc, char **argv)
   bool teardown = false;
   bool readonly = false;
   off_t offset = 0;
+  int sectsize = 512;
   bool badarg = false;
   int ret = ERROR;
   int option;
@@ -701,13 +680,13 @@ int cmd_losetup(FAR struct nsh_vtbl_s *vtbl, int argc, char **argv)
   /* Get the losetup options:  Two forms are supported:
    *
    *   losetup -d <loop-device>
-   *   losetup [-o <offset>] [-r] <loop-device> <filename>
+   *   losetup [-o <offset>] [-r] [-s <sectsize> ] <loop-device> <filename>
    *
    * NOTE that the -o and -r options are accepted with the -d option, but
    * will be ignored.
    */
 
-  while ((option = getopt(argc, argv, "d:o:r")) != ERROR)
+  while ((option = getopt(argc, argv, "d:o:rs:")) != ERROR)
     {
       switch (option)
         {
@@ -724,6 +703,10 @@ int cmd_losetup(FAR struct nsh_vtbl_s *vtbl, int argc, char **argv)
           readonly = true;
           break;
 
+        case 's':
+          sectsize = atoi(optarg);
+          break;
+
         case '?':
         default:
           nsh_error(vtbl, g_fmtarginvalid, argv[0]);
@@ -800,7 +783,7 @@ int cmd_losetup(FAR struct nsh_vtbl_s *vtbl, int argc, char **argv)
 
       setup.devname  = loopdev;   /* The loop block device to be created */
       setup.filename = filepath;  /* The file or character device to use */
-      setup.sectsize = 512;       /* The sector size to use with the block device */
+      setup.sectsize = sectsize;  /* The sector size to use with the block device */
       setup.offset   = offset;    /* An offset that may be applied to the device */
       setup.readonly = readonly;  /* True: Read access will be supported only */
 
@@ -1215,16 +1198,56 @@ int cmd_ls(FAR struct nsh_vtbl_s *vtbl, int argc, char **argv)
 #ifndef CONFIG_NSH_DISABLE_MKDIR
 int cmd_mkdir(FAR struct nsh_vtbl_s *vtbl, int argc, char **argv)
 {
-  FAR char *fullpath = nsh_getfullpath(vtbl, argv[1]);
+  FAR char *fullpath = NULL;
+  bool parent = false;
   int ret = ERROR;
+  int option;
+
+  while ((option = getopt(argc, argv, "p")) != ERROR)
+    {
+      switch (option)
+        {
+          case 'p':
+            parent = true;
+            break;
+        }
+    }
+
+  if (optind < argc)
+    {
+      fullpath = nsh_getfullpath(vtbl, argv[optind]);
+    }
 
   if (fullpath != NULL)
     {
-      ret = mkdir(fullpath, 0777);
-      if (ret < 0)
+      char *slash = parent ? fullpath : "";
+
+      for (; ; )
         {
-          nsh_error(vtbl, g_fmtcmdfailed, argv[0], "mkdir", NSH_ERRNO);
-        }
+          slash = strchr(slash, '/');
+          if (slash != NULL)
+            {
+              *slash = '\0';
+            }
+
+          ret = mkdir(fullpath, 0777);
+
+          if (ret < 0 && (errno != EEXIST || !parent))
+            {
+              nsh_error(vtbl, g_fmtcmdfailed,
+                        fullpath, "mkdir", NSH_ERRNO);
+              break;
+            }
+
+          if (slash != NULL)
+            {
+              *slash++ = '/';
+            }
+          else
+            {
+              break;
+            }
+         }
 
       nsh_freefullpath(fullpath);
     }
@@ -1851,7 +1874,7 @@ int cmd_cmp(FAR struct nsh_vtbl_s *vtbl, int argc, char **argv)
       if (nbytesread1 != nbytesread2 ||
           memcmp(buf1, buf2, nbytesread1) != 0)
         {
-          nsh_error(vtbl, "files differ: byte %u\n", total_read);
+          nsh_error(vtbl, "files differ: byte %" PRIuOFF "\n", total_read);
           goto errout_with_fd2;
         }
 
