@@ -75,15 +75,12 @@ int nsh_catfile(FAR struct nsh_vtbl_s *vtbl, FAR const char *cmd,
                   strlen(CONFIG_NSH_PROC_MOUNTPOINT)) == 0)
         {
           nsh_error(vtbl,
-                    "nsh: %s: Could not open %s (is procfs mounted?): %d\n",
-                    cmd, filepath, NSH_ERRNO);
+                    "nsh: %s: Could not open %s (is procfs mounted?)\n",
+                    cmd, filepath);
         }
-      else
 #endif
-        {
-          nsh_error(vtbl, g_fmtcmdfailed, cmd, "open", NSH_ERRNO);
-        }
 
+      nsh_error(vtbl, g_fmtcmdfailed, cmd, "open", NSH_ERRNO);
       return ERROR;
     }
 
@@ -187,7 +184,7 @@ int nsh_catfile(FAR struct nsh_vtbl_s *vtbl, FAR const char *cmd,
  *
  * Description:
  *   Read a small file into a user-provided buffer.  The data is assumed to
- *   be a string and is guaranteed to be NUL-termined.  An error occurs if
+ *   be a string and is guaranteed to be NUL-terminated.  An error occurs if
  *   the file content (+terminator)  will not fit into the provided 'buffer'.
  *
  * Input Parameters:
@@ -295,8 +292,8 @@ int nsh_readfile(FAR struct nsh_vtbl_s *vtbl, FAR const char *cmd,
  * Input Paratemets:
  *   vtbl     - session vtbl
  *   cmd      - NSH command name to use in error reporting
- *   buffer   - The pointer of writting buffer
- *   len      - The length of writting buffer
+ *   buffer   - The pointer of writing buffer
+ *   len      - The length of writing buffer
  *   filepath - The full path to the file to be dumped
  *
  * Returned Value:
@@ -322,15 +319,12 @@ int nsh_writefile(FAR struct nsh_vtbl_s *vtbl, FAR const char *cmd,
                   strlen(CONFIG_NSH_PROC_MOUNTPOINT)) == 0)
         {
           nsh_error(vtbl,
-                    "nsh: %s: Could not open %s (is procfs mounted?): %d\n",
-                    cmd, filepath, NSH_ERRNO);
+                    "nsh: %s: Could not open %s (is procfs mounted?)\n",
+                    cmd, filepath);
         }
-      else
 #endif
-        {
-          nsh_error(vtbl, g_fmtcmdfailed, cmd, "open", NSH_ERRNO);
-        }
 
+      nsh_error(vtbl, g_fmtcmdfailed, cmd, "open", NSH_ERRNO);
       return ERROR;
     }
 
@@ -384,15 +378,12 @@ int nsh_foreach_direntry(FAR struct nsh_vtbl_s *vtbl, FAR const char *cmd,
                   strlen(CONFIG_NSH_PROC_MOUNTPOINT)) == 0)
         {
           nsh_error(vtbl,
-                    "nsh: %s: Could not open %s (is procfs mounted?): %d\n",
-                    cmd, dirpath, NSH_ERRNO);
-        }
-      else
-#endif
-        {
-          nsh_error(vtbl, g_fmtnosuch, cmd, "directory", dirpath);
+                    "nsh: %s: Could not open %s (is procfs mounted?)\n",
+                    cmd, dirpath);
         }
 
+#endif
+      nsh_error(vtbl, g_fmtcmdfailed, cmd, "opendir", NSH_ERRNO);
       return ERROR;
     }
 
@@ -490,3 +481,39 @@ FAR char *nsh_trimspaces(FAR char *str)
   return trimmed;
 }
 #endif
+
+/****************************************************************************
+ * Name: nsh_getdirpath
+ *
+ * Description:
+ *   Combine dirpath with a file/path, this will generated a new string,
+ *   which need free outside.
+ *
+ * Input Parameters:
+ *   dirpath - the dirpath
+ *   path    - the file/path
+ *
+ * Returned value:
+ *   The new string pointer, need free in caller.
+ *
+ ****************************************************************************/
+
+#ifdef NSH_HAVE_IOBUFFER
+FAR char *nsh_getdirpath(FAR struct nsh_vtbl_s *vtbl,
+                         FAR const char *dirpath, FAR const char *path)
+{
+  /* Handle the case where all that is left is '/' */
+
+  if (strcmp(dirpath, "/") == 0)
+    {
+      snprintf(vtbl->iobuffer, IOBUFFERSIZE, "/%s", path);
+    }
+  else
+    {
+      snprintf(vtbl->iobuffer, IOBUFFERSIZE, "%s/%s", dirpath, path);
+    }
+
+  vtbl->iobuffer[PATH_MAX] = '\0';
+  return strdup(vtbl->iobuffer);
+}
+#endif
