@@ -121,7 +121,7 @@
 /* Get the larger value */
 
 #ifndef MAX
-#  define MAX(a,b) (a > b ? a : b)
+#  define MAX(a,b) ((a) > (b) ? (a) : (b))
 #endif
 
 /****************************************************************************
@@ -377,8 +377,9 @@ static int nsh_foreach_netdev(nsh_netdev_callback_t callback,
   if (dir == NULL)
     {
       nsh_error(vtbl,
-                "nsh: %s: Could not open %s/net (is procfs mounted?): %d\n",
-                cmd, CONFIG_NSH_PROC_MOUNTPOINT, NSH_ERRNO);
+                "nsh: %s: Could not open %s/net (is procfs mounted?)\n",
+                cmd, CONFIG_NSH_PROC_MOUNTPOINT);
+      nsh_error(vtbl, g_fmtcmdfailed, cmd, "opendir", NSH_ERRNO);
       return ERROR;
     }
 
@@ -558,6 +559,7 @@ int cmd_ifconfig(FAR struct nsh_vtbl_s *vtbl, int argc, char **argv)
 #endif
 #ifdef CONFIG_NET_IPv6
   struct in6_addr addr6;
+  struct in6_addr gip6 = IN6ADDR_ANY_INIT;
 #endif
   int i;
   FAR char *ifname = NULL;
@@ -776,6 +778,10 @@ int cmd_ifconfig(FAR struct nsh_vtbl_s *vtbl, int argc, char **argv)
               gip         = addr.s_addr;
             }
         }
+      else
+        {
+          addr.s_addr = 0;
+        }
 
       netlib_set_ipv4addr(ifname, &addr);
     }
@@ -796,6 +802,7 @@ int cmd_ifconfig(FAR struct nsh_vtbl_s *vtbl, int argc, char **argv)
           inet_pton(AF_INET6, gwip, &addr6);
 
           netlib_set_dripv6addr(ifname, &addr6);
+          gip6 = addr6;
         }
     }
 #endif /* CONFIG_NET_IPv6 */
@@ -878,7 +885,18 @@ int cmd_ifconfig(FAR struct nsh_vtbl_s *vtbl, int argc, char **argv)
   if (inet6)
 #endif
     {
-#warning Missing Logic
+      if (dns != NULL)
+        {
+          ninfo("DNS: %s\n", dns);
+          inet_pton(AF_INET6, dns, &addr6);
+        }
+      else
+        {
+          ninfo("DNS: Default\n");
+          addr6 = gip6;
+        }
+
+      netlib_set_ipv6dnsaddr(&addr6);
     }
 #endif /* CONFIG_NET_IPv6 */
 
@@ -954,6 +972,9 @@ int cmd_ifconfig(FAR struct nsh_vtbl_s *vtbl, int argc, char **argv)
 #ifdef CONFIG_NET_IPv4
   UNUSED(gip);
 #endif
+#ifdef CONFIG_NET_IPv6
+  UNUSED(gip6);
+#endif
 
   return OK;
 }
@@ -1028,6 +1049,7 @@ int cmd_arp(FAR struct nsh_vtbl_s *vtbl, int argc, char **argv)
    * arp -s <ipaddr> <hwaddr>
    */
 
+  memset(&inaddr, 0, sizeof(inaddr));
 #ifdef CONFIG_NETLINK_ROUTE
   if (strcmp(argv[1], "-t") == 0)
     {
@@ -1108,6 +1130,8 @@ int cmd_arp(FAR struct nsh_vtbl_s *vtbl, int argc, char **argv)
 #endif
   if (strcmp(argv[1], "-a") == 0)
     {
+      char hwaddr[20];
+
       if (argc != 3)
         {
           goto errout_toomany;
@@ -1125,7 +1149,7 @@ int cmd_arp(FAR struct nsh_vtbl_s *vtbl, int argc, char **argv)
           goto errout_cmdfaild;
         }
 
-      nsh_output(vtbl, "HWaddr: %s\n",  ether_ntoa(&mac));
+      nsh_output(vtbl, "HWaddr: %s\n", ether_ntoa_r(&mac, hwaddr));
     }
   else if (strcmp(argv[1], "-d") == 0)
     {
