@@ -55,6 +55,10 @@
 #define AUDIO_APB_RECORD         (1 << 4)
 #define AUDIO_APB_PLAY           (1 << 5)
 
+#ifndef MIN
+#  define MIN(a, b)              (((a) < (b)) ? (a) : (b))
+#endif
+
 /****************************************************************************
  * Private Functions
  ****************************************************************************/
@@ -121,7 +125,7 @@ static int nxlooper_opendevice(FAR struct nxlooper_s *plooper)
       struct audio_caps_s caps;
       FAR struct dirent *pdevice;
       FAR DIR *dirp;
-      char path[64];
+      char path[PATH_MAX];
 
       /* Search for a device in the audio device directory */
 
@@ -316,18 +320,18 @@ static void *nxlooper_loopthread(pthread_addr_t pvarg)
 {
   FAR struct nxlooper_s   *plooper = (FAR struct nxlooper_s *)pvarg;
   FAR struct ap_buffer_s  *apb;
-  FAR struct ap_buffer_s  *apbtemp;
   struct dq_queue_s       playdq;
   struct dq_queue_s       recorddq;
   struct audio_msg_s      msg;
   struct audio_buf_desc_s buf_desc;
   struct ap_buffer_info_s recordbuf_info;
   struct ap_buffer_info_s playbuf_info;
-  FAR struct ap_buffer_s  **playbufs;
-  FAR struct ap_buffer_s  **recordbufs;
+  FAR struct ap_buffer_s  **playbufs = NULL;
+  FAR struct ap_buffer_s  **recordbufs = NULL;
   unsigned int            prio;
   ssize_t                 size;
-  bool                    running = true;
+  int                     running = 2;
+  bool                    streaming = true;
   int                     x;
   int                     ret;
 
@@ -492,7 +496,13 @@ static void *nxlooper_loopthread(pthread_addr_t pvarg)
           /* An audio buffer is being dequeued by the driver */
 
           case AUDIO_MSG_DEQUEUE:
+            if (!streaming)
+              {
+                break;
+              }
+
             apb = msg.u.ptr;
+            apb->curbyte = 0;
             if (apb->flags & AUDIO_APB_PLAY)
               {
                 dq_addlast(&apb->dq_entry, &playdq);
@@ -502,33 +512,51 @@ static void *nxlooper_loopthread(pthread_addr_t pvarg)
                 dq_addlast(&apb->dq_entry, &recorddq);
               }
 
-              if (dq_count(&playdq) != 0 && dq_count(&recorddq) != 0)
+            if (dq_count(&playdq) != 0 && dq_count(&recorddq) != 0)
               {
-                 apbtemp = (struct ap_buffer_s *)dq_remfirst(&recorddq);
-                 apb = (struct ap_buffer_s *)dq_remfirst(&playdq);
+                FAR struct ap_buffer_s *apbrec;
+                uint32_t copy;
 
-                 apb->nbytes = apbtemp->nbytes;
-                 memcpy(apb->samp, apbtemp->samp, apbtemp->nbytes);
+                apbrec = (FAR struct ap_buffer_s *)dq_peek(&recorddq);
+                apb = (FAR struct ap_buffer_s *)dq_peek(&playdq);
 
-                 ret = nxlooper_enqueuerecordbuffer(plooper, apbtemp);
-                 if (ret == OK)
-                 {
-                   ret = nxlooper_enqueueplaybuffer(plooper, apb);
-                   if (ret == OK &&
-                       plooper->loopstate == NXLOOPER_STATE_RECORDING)
-                   {
-#ifdef CONFIG_AUDIO_MULTI_SESSION
-                     ret = ioctl(plooper->playdev_fd, AUDIOIOC_START,
-                                    (unsigned long)plooper->pplayses);
+                copy = MIN(apbrec->nbytes - apbrec->curbyte,
+                           apb->nmaxbytes - apb->curbyte);
+
+                memcpy(apb->samp + apb->curbyte,
+                       apbrec->samp + apbrec->curbyte, copy);
+                apbrec->curbyte += copy;
+                apb->curbyte += copy;
+
+                if (apbrec->curbyte == apbrec->nbytes)
+                  {
+                    apbrec =
+                        (FAR struct ap_buffer_s *)dq_remfirst(&recorddq);
+                    apbrec->curbyte = 0;
+                    ret = nxlooper_enqueuerecordbuffer(plooper, apbrec);
+                  }
+
+                if (ret == OK && apb->curbyte == apb->nmaxbytes)
+                  {
+                    apb = (FAR struct ap_buffer_s *)dq_remfirst(&playdq);
+                    apb->nbytes = apb->nmaxbytes;
+                    apb->curbyte = 0;
+                    ret = nxlooper_enqueueplaybuffer(plooper, apb);
+                  }
+              }
+
+            if (ret == OK && plooper->loopstate == NXLOOPER_STATE_RECORDING)
+              {
+#ifdef CONFIG_O_MULTI_SESSION
+                ret = ioctl(plooper->playdev_fd, AUDIOIOC_START,
+                            (unsigned long)plooper->pplayses);
 #else
-                     ret = ioctl(plooper->playdev_fd, AUDIOIOC_START, 0);
+                ret = ioctl(plooper->playdev_fd, AUDIOIOC_START, 0);
 #endif
-                     if (ret == OK)
-                       {
-                         plooper->loopstate = NXLOOPER_STATE_LOOPING;
-                       }
-                   }
-                 }
+                if (ret == OK)
+                  {
+                    plooper->loopstate = NXLOOPER_STATE_LOOPING;
+                  }
               }
 
             if (ret == OK)
@@ -554,8 +582,12 @@ static void *nxlooper_loopthread(pthread_addr_t pvarg)
             ioctl(plooper->playdev_fd, AUDIOIOC_STOP, 0);
             ioctl(plooper->recorddev_fd, AUDIOIOC_STOP, 0);
 #endif
+            streaming = false;
 
-            running = false;
+            break;
+
+          case AUDIO_MSG_COMPLETE:
+            running--;
             break;
 
           /* Unknown / unsupported message ID */
@@ -851,11 +883,11 @@ int nxlooper_setdevice(FAR struct nxlooper_s *plooper,
 
   if (caps.ac_controls.b[0] & AUDIO_TYPE_OUTPUT)
     {
-      strncpy(plooper->playdev, pdevice, sizeof(plooper->playdev));
+      strlcpy(plooper->playdev, pdevice, sizeof(plooper->playdev));
     }
   else if (caps.ac_controls.b[0] & AUDIO_TYPE_INPUT)
     {
-      strncpy(plooper->recorddev, pdevice, sizeof(plooper->playdev));
+      strlcpy(plooper->recorddev, pdevice, sizeof(plooper->recorddev));
     }
 
   return OK;
@@ -1297,7 +1329,7 @@ int nxlooper_systemreset(FAR struct nxlooper_s *plooper)
   struct audio_caps_s caps;
   FAR struct dirent   *pdevice;
   FAR DIR             *dirp;
-  char                path[64];
+  char                path[PATH_MAX];
   int                 temp_fd;
 
   /* Search for a device in the audio device directory */
