@@ -142,10 +142,22 @@ static int trace_cmd_start(int index, int argc, FAR char **argv,
 static int trace_cmd_dump(int index, int argc, FAR char **argv,
                           int notectlfd)
 {
+  trace_dump_t type = TRACE_TYPE_LTTNG_KERNEL;
   FAR FILE *out = stdout;
-  int ret;
   bool changed = false;
   bool cont = false;
+  int ret;
+
+  /* Usage: trace dump [-a] "Custom Format : Android SysTrace" */
+
+  if (index < argc)
+    {
+      if (strcmp(argv[index], "-a") == 0)
+        {
+          index++;
+          type = TRACE_TYPE_ANDROID;
+        }
+    }
 
   /* Usage: trace dump [-c][<filename>] */
 
@@ -189,7 +201,7 @@ static int trace_cmd_dump(int index, int argc, FAR char **argv,
 
   /* Dump the trace data */
 
-  ret = trace_dump(out);
+  ret = trace_dump(type, out);
 
   if (changed)
     {
@@ -485,29 +497,30 @@ static int trace_cmd_switch(int index, int argc, FAR char **argv,
 
   /* Parse the setting parameters */
 
-  if (argv[index][0] == '-' || argv[index][0] == '+')
+  if (index < argc)
     {
-      enable = (argv[index][0] == '+');
-      if (enable ==
-          ((mode.flag & NOTE_FILTER_MODE_FLAG_SWITCH) != 0))
+      if (argv[index][0] == '-' || argv[index][0] == '+')
         {
-          /* Already set */
+          enable = (argv[index++][0] == '+');
+          if (enable ==
+              ((mode.flag & NOTE_FILTER_MODE_FLAG_SWITCH) != 0))
+            {
+              /* Already set */
 
-          return false;
+              return index;
+            }
+
+          if (enable)
+            {
+              mode.flag |= NOTE_FILTER_MODE_FLAG_SWITCH;
+            }
+          else
+            {
+              mode.flag &= ~NOTE_FILTER_MODE_FLAG_SWITCH;
+            }
+
+          ioctl(notectlfd, NOTECTL_SETMODE, (unsigned long)&mode);
         }
-
-      if (enable)
-        {
-          mode.flag |= NOTE_FILTER_MODE_FLAG_SWITCH;
-        }
-      else
-        {
-          mode.flag &= ~NOTE_FILTER_MODE_FLAG_SWITCH;
-        }
-
-      ioctl(notectlfd, NOTECTL_SETMODE, (unsigned long)&mode);
-
-      index++;
     }
 
   return index;
@@ -735,29 +748,30 @@ static int trace_cmd_print(int index, int argc, FAR char **argv,
 
   /* Parse the setting parameters */
 
-  if (argv[index][0] == '-' || argv[index][0] == '+')
+  if (index < argc)
     {
-      enable = (argv[index][0] == '+');
-      if (enable ==
-          ((mode.flag & NOTE_FILTER_MODE_FLAG_DUMP) != 0))
+      if (argv[index][0] == '-' || argv[index][0] == '+')
         {
-          /* Already set */
+          enable = (argv[index++][0] == '+');
+          if (enable ==
+              ((mode.flag & NOTE_FILTER_MODE_FLAG_DUMP) != 0))
+            {
+              /* Already set */
 
-          return false;
+              return index;
+            }
+
+          if (enable)
+            {
+              mode.flag |= NOTE_FILTER_MODE_FLAG_DUMP;
+            }
+          else
+            {
+              mode.flag &= ~NOTE_FILTER_MODE_FLAG_DUMP;
+            }
+
+          ioctl(notectlfd, NOTECTL_SETMODE, (unsigned long)&mode);
         }
-
-      if (enable)
-        {
-          mode.flag |= NOTE_FILTER_MODE_FLAG_DUMP;
-        }
-      else
-        {
-          mode.flag &= ~NOTE_FILTER_MODE_FLAG_DUMP;
-        }
-
-      ioctl(notectlfd, NOTECTL_SETMODE, (unsigned long)&mode);
-
-      index++;
     }
 
   return index;
@@ -773,37 +787,40 @@ static void show_usage(void)
   fprintf(stderr,
           "\nUsage: trace <subcommand>...\n"
           "Subcommand:\n"
-          "  start [-c][<duration>]          :"
+          " start   [-c][<duration>]            :"
                                 " Start task tracing\n"
-          "  stop                            :"
+          " stop                                :"
                                 " Stop task tracing\n"
 #ifdef CONFIG_SYSTEM_SYSTEM
-          "  cmd [-c] <command> [<args>...]  :"
+          " cmd     [-c] <command> [<args>...]  :"
                                 " Get the trace while running <command>\n"
 #endif
 #ifdef CONFIG_DRIVER_NOTERAM
-          "  dump [-c][<filename>]           :"
+          " dump    [-a][-c][<filename>]        :"
                                 " Output the trace result\n"
+          "                                       [-a] <Android SysTrace>\n"
 #endif
-          "  mode [{+|-}{o|w|s|a|i|d}...]        :"
+          " mode    [{+|-}{o|w|s|a|i|d}...]     :"
                                 " Set task trace options\n"
 #ifdef CONFIG_SCHED_INSTRUMENTATION_SWITCH
-          "  switch [+|-] :"
+          " switch  [+|-]                       :"
                                 " Configure switch trace filter\n"
 #endif
 #ifdef CONFIG_SCHED_INSTRUMENTATION_SYSCALL
-          "  syscall [{+|-}<syscallname>...] :"
+          " syscall [{+|-}<syscallname>...]     :"
                                 " Configure syscall trace filter\n"
 #endif
 #ifdef CONFIG_SCHED_INSTRUMENTATION_IRQHANDLER
-          "  irq [{+|-}<irqnum>...]          :"
+          " irq     [{+|-}<irqnum>...]          :"
                                 " Configure IRQ trace filter\n"
 #endif
 #ifdef CONFIG_SCHED_INSTRUMENTATION_DUMP
-          "  print [+|-] :"
+          " print   [+|-]                       :"
                                 " Configure dump trace filter\n"
 #endif
          );
+
+  fflush(stderr);
 }
 
 /****************************************************************************
