@@ -32,10 +32,6 @@
  * Pre-processor Definitions
  ****************************************************************************/
 
-#ifndef NULL
-# define NULL (void*)0
-#endif
-
 /****************************************************************************
  * Private Data
  ****************************************************************************/
