@@ -49,7 +49,7 @@
 #define sched_unlock()
 
 #ifndef MIN
-# define MIN(a,b) (((a) < (b)) ? (a) : (b))
+#  define MIN(a,b) ((a) < (b) ? (a) : (b))
 #endif
 
 /****************************************************************************
