@@ -50,11 +50,10 @@
 #define PRIO_LO_NDX   1
 
 #ifndef MIN
-# define MIN(a,b) (((a) < (b)) ? (a) : (b))
+#  define MIN(a,b) ((a) < (b) ? (a) : (b))
 #endif
-
 #ifndef MAX
-# define MAX(a,b) (((a) > (b)) ? (a) : (b))
+#  define MAX(a,b) ((a) > (b) ? (a) : (b))
 #endif
 
 /****************************************************************************
