@@ -59,7 +59,7 @@
 #endif
 
 #ifndef MIN
-#  define MIN(a,b)  (((a) < (b)) ? (a) : (b))
+#  define MIN(a,b) ((a) < (b) ? (a) : (b))
 #endif
 
 #define SOCKET_BASE  10000
@@ -246,8 +246,9 @@ static int _send_ack_common(int fd,
                             uint64_t xid,
                             FAR struct usrsock_message_req_ack_s *resp)
 {
-  resp->head.msgid = USRSOCK_MESSAGE_RESPONSE_ACK;
-  resp->head.flags = 0;
+  resp->head.msgid  = USRSOCK_MESSAGE_RESPONSE_ACK;
+  resp->head.flags  = 0;
+  resp->head.events = 0;
   resp->xid = xid;
 
   /* Send ACK response. */
@@ -447,11 +448,29 @@ static int usock_send_event(int fd, FAR struct gs2200m_s *priv,
     }
 
   event.usockid = i + SOCKET_BASE;
-  event.events  = events;
+  event.head.events = events;
 
   return _write_to_usock(fd, &event, sizeof(event));
 }
 
+/****************************************************************************
+ * Name: usock_sendevent_toall
+ ****************************************************************************/
+
+static void usock_sendevent_toall(FAR struct gs2200m_s *priv, int fd)
+{
+  int i;
+
+  for (i = 0; i < SOCKET_COUNT; i++)
+    {
+      if (priv->sockets[i].state != CLOSED)
+        {
+          usock_send_event(fd, priv, &priv->sockets[i],
+                           USRSOCK_EVENT_RECVFROM_AVAIL);
+        }
+    }
+}
+
 /****************************************************************************
  * Name: socket_request
  ****************************************************************************/
@@ -883,6 +902,7 @@ static int recvfrom_request(int fd, FAR struct gs2200m_s *priv,
 {
   FAR struct usrsock_request_recvfrom_s *req = hdrbuf;
   struct usrsock_message_datareq_ack_s resp;
+  struct usrsock_message_req_ack_s resp1;
   struct gs2200m_recv_msg rmsg;
   FAR struct usock_s *usock;
   int ret = 0;
@@ -951,8 +971,9 @@ prepare:
   memset(&resp, 0, sizeof(resp));
   resp.reqack.result = ret;
   resp.reqack.xid = req->head.xid;
-  resp.reqack.head.msgid = USRSOCK_MESSAGE_RESPONSE_DATA_ACK;
-  resp.reqack.head.flags = 0;
+  resp.reqack.head.msgid  = USRSOCK_MESSAGE_RESPONSE_DATA_ACK;
+  resp.reqack.head.flags  = 0;
+  resp.reqack.head.events = 0;
 
   if (0 <= ret)
     {
@@ -965,6 +986,14 @@ prepare:
           usock_send_event(fd, priv, usock,
                            USRSOCK_EVENT_REMOTE_CLOSED
                            );
+
+          /* Send ack only */
+
+          memset(&resp1, 0, sizeof(resp1));
+          resp1.result = ret;
+          ret = _send_ack_common(fd, req->head.xid, &resp1);
+
+          goto err_out;
         }
     }
 
@@ -1199,8 +1228,9 @@ prepare:
 
   memset(&resp, 0, sizeof(resp));
   resp.reqack.xid = req->head.xid;
-  resp.reqack.head.msgid = USRSOCK_MESSAGE_RESPONSE_DATA_ACK;
-  resp.reqack.head.flags = 0;
+  resp.reqack.head.msgid  = USRSOCK_MESSAGE_RESPONSE_DATA_ACK;
+  resp.reqack.head.flags  = 0;
+  resp.reqack.head.events = 0;
 
   if (0 == ret)
     {
@@ -1387,8 +1417,9 @@ prepare:
 
   memset(&resp, 0, sizeof(resp));
   resp.reqack.xid = req->head.xid;
-  resp.reqack.head.msgid = USRSOCK_MESSAGE_RESPONSE_DATA_ACK;
-  resp.reqack.head.flags = 0;
+  resp.reqack.head.msgid  = USRSOCK_MESSAGE_RESPONSE_DATA_ACK;
+  resp.reqack.head.flags  = 0;
+  resp.reqack.head.events = 0;
   resp.reqack.result = ret;
 
   if (0 == ret)
@@ -1471,8 +1502,9 @@ prepare:
 
   memset(&resp, 0, sizeof(resp));
   resp.reqack.xid = req->head.xid;
-  resp.reqack.head.msgid = USRSOCK_MESSAGE_RESPONSE_DATA_ACK;
-  resp.reqack.head.flags = 0;
+  resp.reqack.head.msgid  = USRSOCK_MESSAGE_RESPONSE_DATA_ACK;
+  resp.reqack.head.flags  = 0;
+  resp.reqack.head.events = 0;
   resp.reqack.result = ret;
 
   if (0 == ret)
@@ -1575,8 +1607,9 @@ static int ioctl_request(int fd, FAR struct gs2200m_s *priv,
     {
       resp2.reqack.result = ret;
       resp2.reqack.xid = req->head.xid;
-      resp2.reqack.head.msgid = USRSOCK_MESSAGE_RESPONSE_DATA_ACK;
-      resp2.reqack.head.flags = 0;
+      resp2.reqack.head.msgid  = USRSOCK_MESSAGE_RESPONSE_DATA_ACK;
+      resp2.reqack.head.flags  = 0;
+      resp2.reqack.head.events = 0;
       resp2.valuelen_nontrunc = sizeof(imsg.ifr);
       resp2.valuelen = sizeof(imsg.ifr);
 
@@ -1657,21 +1690,37 @@ static int gs2200m_loop(FAR struct gs2200m_s *priv)
           ret = read(fd[1], &cid, sizeof(cid));
           ASSERT(ret == sizeof(cid));
 
-          /* find usock by the cid */
+          /* Check if all socket destroy or not */
 
-          usock = gs2200m_find_socket_by_cid(priv, cid);
-
-          if (NULL == usock)
+          if (cid == DISASSOCIATION_CID)
             {
-              gs2200m_printf("=== %s: cid=%c not found (ignored)\n",
-                             __func__, cid);
+              gs2200m_printf("=== %s: Disassocitaion event\n",
+                            __func__);
+
+              /* To release sockets blocking in user-sock,
+               * send event to all opened sockets.
+               */
+
+              usock_sendevent_toall(priv, fd[0]);
             }
           else
             {
-              /* send event to call xxxx_request() */
+              /* find usock by the cid */
 
-              usock_send_event(fd[0], priv, usock,
-                               USRSOCK_EVENT_RECVFROM_AVAIL);
+              usock = gs2200m_find_socket_by_cid(priv, cid);
+
+              if (NULL == usock)
+                {
+                  gs2200m_printf("=== %s: cid=%c not found (ignored)\n",
+                                __func__, cid);
+                }
+              else
+                {
+                  /* send event to call xxxx_request() */
+
+                  usock_send_event(fd[0], priv, usock,
+                                  USRSOCK_EVENT_RECVFROM_AVAIL);
+                }
             }
         }
     }
