@@ -1,32 +1,20 @@
 /****************************************************************************
  * apps/wireless/iwpan/src/iwpan.c
  *
- *   Copyright (C) 2017 Verge Inc. All rights reserved.
- *   Copyright (C) 2017 Gregory Nutt. All rights reserved.
- *   Author: Anthony Merlino <anthony@vergeaero.com>
- *           Gregory Nutt <gnutt@nuttx.org>
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.  The
+ * ASF licenses this file to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance with the
+ * License.  You may obtain a copy of the License at
  *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions are met:
+ *   http://www.apache.org/licenses/LICENSE-2.0
  *
- *  - Redistributions of  source code must  retain the above copyright notice,
- *    this list of conditions and the following disclaimer.
- *
- *  - Redistributions in binary form must reproduce the above copyright
- *    notice, this list of  conditions and the  following disclaimer in the
- *    documentation and/or other materials provided with the distribution.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
- * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
- * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND  FITNESS FOR A PARTICULAR
- * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
- * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
- * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
- * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
- * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
- * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
- * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
- * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+ * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
+ * License for the specific language governing permissions and limitations
+ * under the License.
  *
  ****************************************************************************/
 
@@ -43,31 +31,6 @@
 #include "wireless/ieee802154.h"
 #include "wireless/iwpan.h"
 
-/****************************************************************************
- * Pre-processor Definitions
- ****************************************************************************/
-
-/* The address family that we used to create the socket really does not
- * matter.  It should, however, be valid in the current configuration.
- */
-
-#if defined(CONFIG_NET_IPv4)
-#  define PF_INETX PF_INET
-#elif defined(CONFIG_NET_IPv6)
-#  define PF_INETX PF_INET6
-#endif
-
-/* SOCK_DGRAM is the preferred socket type to use when we just want a
- * socket for performing driver ioctls.  However, we can't use SOCK_DRAM
- * if UDP is disabled.
- */
-
-#ifdef CONFIG_NET_UDP
-# define SOCK_IWPAN SOCK_DGRAM
-#else
-# define SOCK_IWPAN SOCK_STREAM
-#endif
-
 /****************************************************************************
  * Private Types
  ****************************************************************************/
@@ -236,7 +199,8 @@ static uint8_t iwpan_char2nibble(char ch)
     }
   else
     {
-      fprintf(stderr, "ERROR: Unexpected character in hex value: %02x\n", ch);
+      fprintf(stderr,
+              "ERROR: Unexpected character in hex value: %02x\n", ch);
       exit(EXIT_FAILURE);
     }
 }
@@ -420,12 +384,12 @@ static void iwpan_show_cmd(int sock, FAR const char *ifname)
 static void iwpan_cca_cmd(int sock, FAR const char *ifname,
                           FAR const char *ccastr)
 {
+  int ret;
   union
   {
     struct ieee802154_cca_s cca;
     uint8_t b;
   } u;
-  int ret;
 
   /* Convert input strings to values */
 
@@ -589,7 +553,7 @@ static void iwpan_promisc_cmd(int sock, FAR const char *ifname,
 static void iwpan_saddr_cmd(int sock, FAR const char *ifname,
                             FAR const char *addrstr)
 {
-   uint16_t saddr;
+  uint16_t saddr;
   int ret;
 
   /* Convert input strings to values */
@@ -734,7 +698,7 @@ int main(int argc, FAR char *argv[])
 
   /* Create a communication socket */
 
-  sock = socket(PF_INETX, SOCK_IWPAN, 0);
+  sock = socket(NET_SOCK_FAMILY, NET_SOCK_TYPE, NET_SOCK_PROTOCOL);
   if (sock < 0)
     {
       fprintf(stderr, "ERROR: iwpan_make_socket() failed: %d\n", sock);
