@@ -117,13 +117,13 @@ static const struct wapi_command_s g_wapi_commands[] =
   {"mask",         2, 2, wapi_mask_cmd},
   {"freq",         3, 3, wapi_freq_cmd},
   {"essid",        3, 3, wapi_essid_cmd},
-  {"psk",          3, 3, wapi_psk_cmd},
+  {"psk",          3, 4, wapi_psk_cmd},
   {"disconnect",   1, 1, wapi_disconnect_cmd},
   {"mode",         2, 2, wapi_mode_cmd},
   {"ap",           2, 2, wapi_ap_cmd},
   {"bitrate",      3, 3, wapi_bitrate_cmd},
   {"txpower",      3, 3, wapi_txpower_cmd},
-  {"country",      2, 2, wapi_country_cmd},
+  {"country",      1, 2, wapi_country_cmd},
   {"sense",        1, 1, wapi_sense_cmd},
 #ifdef CONFIG_WIRELESS_WAPI_INITCONF
   {"reconnect",    1, 1, wapi_reconnect_cmd},
@@ -259,6 +259,7 @@ static int wapi_show_cmd(int sock, int argc, FAR char **argv)
   enum wapi_mode_e mode;
   struct ether_addr ap;
   struct in_addr addr;
+  char country[4];
   double tmpfreq;
   int bitrate;
   int txpower;
@@ -266,6 +267,7 @@ static int wapi_show_cmd(int sock, int argc, FAR char **argv)
   int sense;
   int chan;
   int ret;
+  char inetaddr[INET_ADDRSTRLEN];
 
   printf("%s Configuration:\n", ifname);
 
@@ -280,7 +282,8 @@ static int wapi_show_cmd(int sock, int argc, FAR char **argv)
     }
   else
     {
-      printf("       IP: %s\n", inet_ntoa(addr));
+      printf("       IP: %s\n", inet_ntoa_r(addr, inetaddr,
+                                            sizeof(inetaddr)));
     }
 
   /* Get netmask */
@@ -293,7 +296,8 @@ static int wapi_show_cmd(int sock, int argc, FAR char **argv)
     }
   else
     {
-      printf("  NetMask: %s\n", inet_ntoa(addr));
+      printf("  NetMask: %s\n", inet_ntoa_r(addr, inetaddr,
+                                            sizeof(inetaddr)));
     }
 
   /* Get frequency */
@@ -404,6 +408,15 @@ static int wapi_show_cmd(int sock, int argc, FAR char **argv)
       printf("    Sense: %d\n", sense);
     }
 
+  /* Get Country Code */
+
+  memset(country, 0, sizeof(country));
+  ret = wapi_get_country(sock, ifname, country);
+  if (ret == 0)
+    {
+      printf("  Country: %s\n", country);
+    }
+
   return 0;
 }
 
@@ -521,15 +534,64 @@ static int wapi_essid_cmd(int sock, int argc, FAR char **argv)
 static int wapi_psk_cmd(int sock, int argc, FAR char **argv)
 {
   enum wpa_alg_e alg_flag;
+  uint8_t auth_wpa;
+  int cipher;
+  int ret;
 
   /* Convert input strings to values */
 
   alg_flag = (enum wpa_alg_e)wapi_str2ndx(argv[2], g_wapi_alg_flags);
 
-  /* Set the Passphrase */
+  if (argc > 3)
+    {
+      auth_wpa = atoi(argv[3]);
+    }
+  else
+    {
+      auth_wpa = IW_AUTH_WPA_VERSION_WPA2;
+    }
 
-  return wpa_driver_wext_set_key_ext(sock, argv[0], alg_flag,
-                                     argv[1], strlen(argv[1]));
+  switch (alg_flag)
+    {
+      case WPA_ALG_NONE:
+        cipher = IW_AUTH_CIPHER_NONE;
+        break;
+
+      case WPA_ALG_WEP:
+        cipher = IW_AUTH_CIPHER_WEP40;
+        break;
+
+      case WPA_ALG_TKIP:
+        cipher = IW_AUTH_CIPHER_TKIP;
+        break;
+
+      case WPA_ALG_CCMP:
+        cipher = IW_AUTH_CIPHER_CCMP;
+        break;
+
+      default:
+        return -1;
+    }
+
+  ret = wpa_driver_wext_set_auth_param(sock, argv[0],
+                                       IW_AUTH_WPA_VERSION,
+                                       auth_wpa);
+  if (ret >= 0)
+    {
+      ret = wpa_driver_wext_set_auth_param(sock, argv[0],
+                                           IW_AUTH_CIPHER_PAIRWISE,
+                                           cipher);
+
+      /* Set the Passphrase */
+
+      if (ret >= 0)
+        {
+          ret = wpa_driver_wext_set_key_ext(sock, argv[0], alg_flag,
+                                            argv[1], strlen(argv[1]));
+        }
+    }
+
+  return ret;
 }
 
 /****************************************************************************
@@ -708,14 +770,14 @@ static int wapi_scan_results_cmd(int sock, int argc, FAR char **argv)
 
   /* Print found aps */
 
-  printf("bssid / frequency / signal level / ssid\n");
+  printf("bssid / frequency / signal level / encode / ssid\n");
   for (info = list.head.scan; info; info = info->next)
     {
-      printf("%02x:%02x:%02x:%02x:%02x:%02x\t%g\t%d\t%s\n",
+      printf("%02x:%02x:%02x:%02x:%02x:%02x\t%g\t%d\t%04x\t%s\n",
              info->ap.ether_addr_octet[0], info->ap.ether_addr_octet[1],
              info->ap.ether_addr_octet[2], info->ap.ether_addr_octet[3],
-             info->ap.ether_addr_octet[4],  info->ap.ether_addr_octet[5],
-             info->freq, info->rssi, info->essid);
+             info->ap.ether_addr_octet[4], info->ap.ether_addr_octet[5],
+             info->freq, info->rssi, info->encode, info->essid);
     }
 
   /* Free ap list */
@@ -757,7 +819,7 @@ static int wapi_scan_cmd(int sock, int argc, FAR char **argv)
  * Name: wapi_country_cmd
  *
  * Description:
- *  Set the country code
+ *  Set/Get the country code
  *
  * Returned Value:
  *   None
@@ -766,6 +828,20 @@ static int wapi_scan_cmd(int sock, int argc, FAR char **argv)
 
 static int wapi_country_cmd(int sock, int argc, FAR char **argv)
 {
+  char country[4];
+  int ret;
+
+  if (argc == 1)
+    {
+      ret = wapi_get_country(sock, argv[0], country);
+      if (ret == 0)
+        {
+          printf("%s\n", country);
+        }
+
+      return ret;
+    }
+
   return wapi_set_country(sock, argv[0], argv[1]);
 }
 
@@ -840,6 +916,7 @@ static int wapi_reconnect_cmd(int sock, int argc, FAR char **argv)
 static int wapi_save_config_cmd(int sock, int argc, FAR char **argv)
 {
   char essid[WAPI_ESSID_MAX_SIZE + 1];
+  char bssid[20];
   enum wapi_essid_flag_e essid_flag;
   struct wpa_wconfig_s conf;
   struct ether_addr ap;
@@ -885,7 +962,7 @@ static int wapi_save_config_cmd(int sock, int argc, FAR char **argv)
       return ret;
     }
 
-  conf.bssid = ether_ntoa(&ap);
+  conf.bssid = ether_ntoa_r(&ap, bssid);
 
   memset(psk, 0, sizeof(psk));
   ret = wpa_driver_wext_get_key_ext(sock,
@@ -957,8 +1034,8 @@ static void wapi_showusage(FAR const char *progname, int exitcode)
                    progname);
   fprintf(stderr, "\t%s essid        <ifname> <essid>      <index/flag>\n",
                    progname);
-  fprintf(stderr, "\t%s psk          <ifname> <passphrase> <index/flag>\n",
-                   progname);
+  fprintf(stderr, "\t%s psk          <ifname> <passphrase> <index/flag> "
+                  "<wpa>\n", progname);
   fprintf(stderr, "\t%s disconnect   <ifname>\n", progname);
   fprintf(stderr, "\t%s mode         <ifname>              <index/mode>\n",
                    progname);
